package de.donmanfred;

import com.samsung.android.sdk.healthdata.HealthConstants.StepCount;
import com.samsung.android.sdk.healthdata.HealthDataResolver;
import com.samsung.android.sdk.healthdata.HealthDataResolver.AggregateRequest;
import com.samsung.android.sdk.healthdata.HealthDataResolver.DeleteRequest;
import com.samsung.android.sdk.healthdata.HealthDataResolver.InsertRequest;
import com.samsung.android.sdk.healthdata.HealthDataResolver.ReadRequest;
import com.samsung.android.sdk.healthdata.HealthDataResolver.ReadResult;
import com.samsung.android.sdk.healthdata.HealthDataResolver.UpdateRequest;
import com.samsung.android.sdk.healthdata.HealthDataStore;
import com.samsung.android.sdk.healthdata.HealthResultHolder;
import com.samsung.android.sdk.healthdata.HealthDataResolver.AggregateResult;
import com.samsung.android.sdk.healthdata.HealthResultHolder.BaseResult;
import com.samsung.android.sdk.healthdata.HealthResultHolder.ResultListener;

import android.database.Cursor;
import android.os.Handler;
import anywheresoftware.b4a.AbsObjectWrapper;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Events;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.objects.collections.List;
import anywheresoftware.b4a.objects.collections.Map;
import anywheresoftware.b4a.objects.collections.Map.MyMap;

@ShortName("HealthDataResolver")
//@Permissions(values={"android.permission.INTERNET", "android.permission.ACCESS_NETWORK_STATE"})
@Events(values={
		"onAggregateResult(count As int, valuetype As String, status As int, data As Cursor)",
		"onReadResult(count As int, valuetype As String, status As int, data As List)",
		"onInsertResult(count As int, status As int)",
		"onUpdateResult(count As int, status As int)",
		"onDeleteResult(count As int, status As int)"
		
})
//@DependsOn(values={"samsung-digital-health-healthdata-1.2.1"})

/**
 * com.android.support:support-v4
 * com.android.support:appcompat-v7
 * com.android.support:cardview-v7
 * com.android.support:gridlayout-v7
 * com.android.support:mediarouter-v7
 * com.android.support:palette-v7
 * com.android.support:recyclerview-v
 * com.android.support:preference-v7
 * com.android.support:support-v13
 * com.google.firebase:firebase-database
 */

public class HealthDataResolverWrapper extends AbsObjectWrapper<HealthDataResolver> {
	private BA ba;
	private String eventName;
	private Handler hdl;
	public void Initialize(final BA ba, String EventName, HealthDataStore store) {
		this.eventName = EventName.toLowerCase(BA.cul);
		this.ba = ba;
		this.hdl = new Handler();
		final HealthDataResolver _obj = new HealthDataResolver(store, hdl);
		final String eventName = EventName.toLowerCase(BA.cul);
		setObject(_obj);
	}
	public void aggregate(AggregateRequest request){
		HealthResultHolder<AggregateResult> resholder = getObject().aggregate(request);
		resholder.setResultListener(new ResultListener<AggregateResult>(){
			@Override
			public void onResult(AggregateResult result) {
	 			if (ba.subExists(eventName + "_onaggregateresult")) {
  				BA.Log("lib:Raising.. "+eventName + "_onaggregateresult()");								
  				//app.raiseEvent(app.context, eventName+"_pagerendered", i, pageCount, filename+"-" + i + ".png");
  				ba.raiseEventFromDifferentThread(this, null, 0, eventName + "_onaggregateresult", true, new Object[] {result.getCount(),result.getDataType(),result.getStatus(),result.getResultCursor()});
  			}else {
  				BA.Log("lib: NOTFOUND '"+eventName + "_onaggregateresult");
  			}
			}}
		);
		//getObject().update(request)
		
	}
	public void update(UpdateRequest request){
		HealthResultHolder<BaseResult> resholder = getObject().update(request);
		resholder.setResultListener(new ResultListener<BaseResult>(){

			@Override
			public void onResult(BaseResult result) {
	 			if (ba.subExists(eventName + "_onupdateresult")) {
  				BA.Log("lib:Raising.. "+eventName + "_onupdateresult()");								
  				//app.raiseEvent(app.context, eventName+"_pagerendered", i, pageCount, filename+"-" + i + ".png");
  				ba.raiseEventFromDifferentThread(this, null, 0, eventName + "_onupdateresult", true, new Object[] {result.getCount(),result.getStatus()});
  			}else {
  				BA.Log("lib: NOTFOUND '"+eventName + "_onupdateresult");
  			}
				
			}
		});
	}
	public void read(ReadRequest request){
		HealthResultHolder<ReadResult> resholder = getObject().read(request);
		resholder.setResultListener(new ResultListener<ReadResult>(){
			@Override
			public void onResult(ReadResult result) {
	 			if (ba.subExists(eventName + "_onreadresult")) {
	 				BA.Log("lib:Raising.. "+eventName + "_onreadresult()");								
          Cursor c = null;
          try {
          	c = result.getResultCursor();
          	if (c == null) {
          		BA.Log("null cursor!");
          		return;
          	}
          	BA.Log("CursorSize="+c.getCount());
          	List l = new anywheresoftware.b4a.objects.collections.List();
          	l.Initialize();

          	// Read the food intake calories of each meal type
          	while (c.moveToNext()) {
          		MyMap m = new anywheresoftware.b4a.objects.collections.Map.MyMap();
          		
          		if (c.getColumnIndex(StepCount.CALORIE) > -1){
          			m.put("CALORIE", c.getInt(c.getColumnIndex(StepCount.CALORIE)));
          		}
          		if (c.getColumnIndex(StepCount.COUNT) > -1){
          			m.put("COUNT", c.getInt(c.getColumnIndex(StepCount.COUNT)));
          		}
          		if (c.getColumnIndex(StepCount.DISTANCE) > -1){
          			m.put("DISTANCE", c.getString(c.getColumnIndex(StepCount.DISTANCE)));
          		}
          		if (c.getColumnIndex(StepCount.SPEED) > -1){
          			m.put("SPEED", c.getString(c.getColumnIndex(StepCount.SPEED)));
          		}
          		if (c.getColumnIndex(StepCount.HEALTH_DATA_TYPE) > -1){
          			m.put("HEALTH_DATA_TYPE", c.getString(c.getColumnIndex(StepCount.HEALTH_DATA_TYPE)));
          		}
          		if (c.getColumnIndex(StepCount.SAMPLE_POSITION_TYPE) > -1){
          			m.put("SAMPLE_POSITION_TYPE", c.getString(c.getColumnIndex(StepCount.SAMPLE_POSITION_TYPE)));
          		}
          		if (c.getColumnIndex(StepCount.CREATE_TIME) > -1){
          			m.put("CREATE_TIME", c.getLong(c.getColumnIndex(StepCount.CREATE_TIME)));
          		}
          		if (c.getColumnIndex(StepCount.DEVICE_UUID) > -1){
          			m.put("DEVICE_UUID", c.getString(c.getColumnIndex(StepCount.DEVICE_UUID)));
          		}
          		if (c.getColumnIndex(StepCount.COUNT) > -1){
          			m.put("END_TIME", c.getLong(c.getColumnIndex(StepCount.END_TIME)));
          		}
          		if (c.getColumnIndex(StepCount.PACKAGE_NAME) > -1){
          			m.put("PACKAGE_NAME", c.getString(c.getColumnIndex(StepCount.PACKAGE_NAME)));
          		}
          		if (c.getColumnIndex(StepCount.START_TIME) > -1){
          			m.put("START_TIME", c.getLong(c.getColumnIndex(StepCount.START_TIME)));
          		}
          		if (c.getColumnIndex(StepCount.TIME_OFFSET) > -1){
          			m.put("TIME_OFFSET", c.getLong(c.getColumnIndex(StepCount.TIME_OFFSET)));
          		}
          		if (c.getColumnIndex(StepCount.UPDATE_TIME) > -1){
          			m.put("UPDATE_TIME", c.getLong(c.getColumnIndex(StepCount.UPDATE_TIME)));
          		}
          		if (c.getColumnIndex(StepCount.UUID) > -1){
          			m.put("UUID", c.getString(c.getColumnIndex(StepCount.UUID)));
          		}
          		l.Add(m);
          	}
          	//app.raiseEvent(app.context, eventName+"_pagerendered", i, pageCount, filename+"-" + i + ".png");
          	ba.raiseEventFromDifferentThread(this, null, 0, eventName + "_onreadresult", true, new Object[] {result.getCount(),result.getDataType(),result.getStatus(),l});
          } finally {
          	if (c != null) {
          		c.close();
          	}
          }
	 			}else {
	 				BA.Log("lib: NOTFOUND '"+eventName + "_onreadresult");
	 			}
				
			}
		});
	}
	public void insert(InsertRequest request){
		HealthResultHolder<BaseResult> resholder = getObject().insert(request);
		resholder.setResultListener(new ResultListener<BaseResult>(){

			@Override
			public void onResult(BaseResult result) {
	 			if (ba.subExists(eventName + "_oninsertresult")) {
  				BA.Log("lib:Raising.. "+eventName + "_oninsertresult()");								
  				//app.raiseEvent(app.context, eventName+"_pagerendered", i, pageCount, filename+"-" + i + ".png");
  				ba.raiseEventFromDifferentThread(this, null, 0, eventName + "_oninsertresult", true, new Object[] {result.getCount(),result.getStatus()});
  			}else {
  				BA.Log("lib: NOTFOUND '"+eventName + "_oninsertresult");
  			}
				
			}});
	}
	public void delete(DeleteRequest request){
		HealthResultHolder<BaseResult> resholder = getObject().delete(request);
		resholder.setResultListener(new ResultListener<BaseResult>(){

			@Override
			public void onResult(BaseResult result) {
	 			if (ba.subExists(eventName + "_ondeleteresult")) {
  				BA.Log("lib:Raising.. "+eventName + "_ondeleteresult()");								
  				//app.raiseEvent(app.context, eventName+"_pagerendered", i, pageCount, filename+"-" + i + ".png");
  				ba.raiseEventFromDifferentThread(this, null, 0, eventName + "_ondeleteresult", true, new Object[] {result.getCount(),result.getStatus()});
  			}else {
  				BA.Log("lib: NOTFOUND '"+eventName + "_ondeleteresult");
  			}
				
			}});
	}
		
}
